@@ -6,9 +6,8 @@ RCPP_MODULE(ManifoldOptim_module) {
 	.constructor<Function,Function,Function>()
 	.constructor<Function,Function>()
 	.constructor<Function>()
-	.field_readonly("objFun", &RProblem::m_objFun)
-	.field_readonly("gradFun", &RProblem::m_gradFun)
-	.field_readonly("hessEtaFun", &RProblem::m_hessEtaFun)
+	.method("objFun", &RProblem::objFun)
+	.method("gradFun", &RProblem::gradFun)
+	.method("hessEtaFun", &RProblem::hessEtaFun)
 	;
 }
-
