@@ -70,7 +70,7 @@ namespace ROPTLIB{
 	void Element::Print(const char *name, bool isonlymain) const
 	{
 		if (TempData.size() > 0 && !isonlymain)
-			printf("=================Main data: %s=========================\n", name);
+			Rprintf("=================Main data: %s=========================\n", name);
 		SmartSpace::Print(name);
 
 		if (TempData.size() > 0 && !isonlymain)
@@ -78,10 +78,10 @@ namespace ROPTLIB{
 			MAP::const_iterator thisiter;
 			for (thisiter = TempData.begin(); thisiter != TempData.end(); thisiter++)
 			{
-				printf("=================Temp data in %s ================\n", name);
+				Rprintf("=================Temp data in %s ================\n", name);
 				thisiter->second->Print(thisiter->first.c_str());
 			}
-			printf("=================end of output: %s=========================\n", name);
+			Rprintf("=================end of output: %s=========================\n", name);
 		}
 	};
 
@@ -112,7 +112,7 @@ namespace ROPTLIB{
 		thisiter = TempData.find(name);
 		if (thisiter == TempData.end())
 		{
-			printf("Error: TempData %s does not exist!\n", name.c_str());
+			Rprintf("Error: TempData %s does not exist!\n", name.c_str());
 			return nullptr;
 		}
 
@@ -125,7 +125,7 @@ namespace ROPTLIB{
 		thisiter = TempData.find(name);
 		if (thisiter == TempData.end())
 		{
-			printf("Error: TempData %s does not exist!\n", name.c_str());
+			Rprintf("Error: TempData %s does not exist!\n", name.c_str());
 			return nullptr;
 		}
 
@@ -179,4 +179,4 @@ namespace ROPTLIB{
 			names[idx].assign(thisiter->first);
 		}
 	};
-}; /*end of ROPTLIB namespace*/
+} /*end of ROPTLIB namespace*/
