@@ -59,4 +59,4 @@ namespace ROPTLIB{
 
 		delete[] temp;
 	}
-}; /*end of ROPTLIB namespace*/
+} /*end of ROPTLIB namespace*/
