@@ -34,5 +34,5 @@ namespace ROPTLIB{
 		integer n;
 		integer p;
 	};
-}; /*end of ROPTLIB namespace*/
+} /*end of ROPTLIB namespace*/
 #endif // end of GRASSRQ_H
